# Stubs for google.ads.google_ads.v6.proto.services.feed_mapping_service_pb2_grpc (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any, Optional

class FeedMappingServiceStub:
    GetFeedMapping: Any = ...
    MutateFeedMappings: Any = ...
    def __init__(self, channel: Any) -> None: ...

class FeedMappingServiceServicer:
    def GetFeedMapping(self, request: Any, context: Any) -> None: ...
    def MutateFeedMappings(self, request: Any, context: Any) -> None: ...

def add_FeedMappingServiceServicer_to_server(servicer: Any, server: Any) -> None: ...

class FeedMappingService:
    @staticmethod
    def GetFeedMapping(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...
    @staticmethod
    def MutateFeedMappings(
        request: Any,
        target: Any,
        options: Any = ...,
        channel_credentials: Optional[Any] = ...,
        call_credentials: Optional[Any] = ...,
        compression: Optional[Any] = ...,
        wait_for_ready: Optional[Any] = ...,
        timeout: Optional[Any] = ...,
        metadata: Optional[Any] = ...,
    ): ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomAudienceTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CustomAudienceTypeValue = typing___NewType("CustomAudienceTypeValue", builtin___int)
    type___CustomAudienceTypeValue = CustomAudienceTypeValue
    CustomAudienceType: _CustomAudienceType
    class _CustomAudienceType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CustomAudienceTypeEnum.CustomAudienceTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(CustomAudienceTypeEnum.CustomAudienceTypeValue, 0)
        UNKNOWN = typing___cast(CustomAudienceTypeEnum.CustomAudienceTypeValue, 1)
        AUTO = typing___cast(CustomAudienceTypeEnum.CustomAudienceTypeValue, 2)
        INTEREST = typing___cast(CustomAudienceTypeEnum.CustomAudienceTypeValue, 3)
        PURCHASE_INTENT = typing___cast(
            CustomAudienceTypeEnum.CustomAudienceTypeValue, 4
        )
        SEARCH = typing___cast(CustomAudienceTypeEnum.CustomAudienceTypeValue, 5)
    UNSPECIFIED = typing___cast(CustomAudienceTypeEnum.CustomAudienceTypeValue, 0)
    UNKNOWN = typing___cast(CustomAudienceTypeEnum.CustomAudienceTypeValue, 1)
    AUTO = typing___cast(CustomAudienceTypeEnum.CustomAudienceTypeValue, 2)
    INTEREST = typing___cast(CustomAudienceTypeEnum.CustomAudienceTypeValue, 3)
    PURCHASE_INTENT = typing___cast(CustomAudienceTypeEnum.CustomAudienceTypeValue, 4)
    SEARCH = typing___cast(CustomAudienceTypeEnum.CustomAudienceTypeValue, 5)
    type___CustomAudienceType = CustomAudienceType
    def __init__(self,) -> None: ...

type___CustomAudienceTypeEnum = CustomAudienceTypeEnum



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads/v5/enums/served_asset_field_type.proto
"""Generated protocol buffer code."""
from google.protobuf import (
    descriptor as _descriptor,
    message as _message,
    reflection as _reflection,
    symbol_database as _symbol_database,
)

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2

DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/ads/googleads/v5/enums/served_asset_field_type.proto",
    package="google.ads.googleads.v5.enums",
    syntax="proto3",
    serialized_options=b"\n!com.google.ads.googleads.v5.enumsB\031ServedAssetFieldTypeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v5/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V5.Enums\312\002\035Google\\Ads\\GoogleAds\\V5\\Enums\352\002!Google::Ads::GoogleAds::V5::Enums",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n;google/ads/googleads/v5/enums/served_asset_field_type.proto\x12\x1dgoogle.ads.googleads.v5.enums\x1a\x1cgoogle/api/annotations.proto"\xa7\x01\n\x18ServedAssetFieldTypeEnum"\x8a\x01\n\x14ServedAssetFieldType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0e\n\nHEADLINE_1\x10\x02\x12\x0e\n\nHEADLINE_2\x10\x03\x12\x0e\n\nHEADLINE_3\x10\x04\x12\x11\n\rDESCRIPTION_1\x10\x05\x12\x11\n\rDESCRIPTION_2\x10\x06\x42\xee\x01\n!com.google.ads.googleads.v5.enumsB\x19ServedAssetFieldTypeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v5/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V5.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V5\\Enums\xea\x02!Google::Ads::GoogleAds::V5::Enumsb\x06proto3',
    dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR],
)


_SERVEDASSETFIELDTYPEENUM_SERVEDASSETFIELDTYPE = _descriptor.EnumDescriptor(
    name="ServedAssetFieldType",
    full_name="google.ads.googleads.v5.enums.ServedAssetFieldTypeEnum.ServedAssetFieldType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="UNKNOWN",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="HEADLINE_1",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="HEADLINE_2",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="HEADLINE_3",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="DESCRIPTION_1",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="DESCRIPTION_2",
            index=6,
            number=6,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=154,
    serialized_end=292,
)
_sym_db.RegisterEnumDescriptor(_SERVEDASSETFIELDTYPEENUM_SERVEDASSETFIELDTYPE)


_SERVEDASSETFIELDTYPEENUM = _descriptor.Descriptor(
    name="ServedAssetFieldTypeEnum",
    full_name="google.ads.googleads.v5.enums.ServedAssetFieldTypeEnum",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[],
    extensions=[],
    nested_types=[],
    enum_types=[_SERVEDASSETFIELDTYPEENUM_SERVEDASSETFIELDTYPE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=125,
    serialized_end=292,
)

_SERVEDASSETFIELDTYPEENUM_SERVEDASSETFIELDTYPE.containing_type = (
    _SERVEDASSETFIELDTYPEENUM
)
DESCRIPTOR.message_types_by_name["ServedAssetFieldTypeEnum"] = _SERVEDASSETFIELDTYPEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ServedAssetFieldTypeEnum = _reflection.GeneratedProtocolMessageType(
    "ServedAssetFieldTypeEnum",
    (_message.Message,),
    {
        "DESCRIPTOR": _SERVEDASSETFIELDTYPEENUM,
        "__module__": "google.ads.googleads.v5.enums.served_asset_field_type_pb2"
        # @@protoc_insertion_point(class_scope:google.ads.googleads.v5.enums.ServedAssetFieldTypeEnum)
    },
)
_sym_db.RegisterMessage(ServedAssetFieldTypeEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.common.custom_parameter_pb2 import (
    CustomParameter as google___ads___googleads___v5___common___custom_parameter_pb2___CustomParameter,
)
from google.ads.google_ads.v5.proto.common.explorer_auto_optimizer_setting_pb2 import (
    ExplorerAutoOptimizerSetting as google___ads___googleads___v5___common___explorer_auto_optimizer_setting_pb2___ExplorerAutoOptimizerSetting,
)
from google.ads.google_ads.v5.proto.common.targeting_setting_pb2 import (
    TargetingSetting as google___ads___googleads___v5___common___targeting_setting_pb2___TargetingSetting,
)
from google.ads.google_ads.v5.proto.enums.ad_group_ad_rotation_mode_pb2 import (
    AdGroupAdRotationModeEnum as google___ads___googleads___v5___enums___ad_group_ad_rotation_mode_pb2___AdGroupAdRotationModeEnum,
)
from google.ads.google_ads.v5.proto.enums.ad_group_status_pb2 import (
    AdGroupStatusEnum as google___ads___googleads___v5___enums___ad_group_status_pb2___AdGroupStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.ad_group_type_pb2 import (
    AdGroupTypeEnum as google___ads___googleads___v5___enums___ad_group_type_pb2___AdGroupTypeEnum,
)
from google.ads.google_ads.v5.proto.enums.bidding_source_pb2 import (
    BiddingSourceEnum as google___ads___googleads___v5___enums___bidding_source_pb2___BiddingSourceEnum,
)
from google.ads.google_ads.v5.proto.enums.targeting_dimension_pb2 import (
    TargetingDimensionEnum as google___ads___googleads___v5___enums___targeting_dimension_pb2___TargetingDimensionEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdGroup(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    id: builtin___int = ...
    name: typing___Text = ...
    status: google___ads___googleads___v5___enums___ad_group_status_pb2___AdGroupStatusEnum.AdGroupStatusValue = ...
    type: google___ads___googleads___v5___enums___ad_group_type_pb2___AdGroupTypeEnum.AdGroupTypeValue = ...
    ad_rotation_mode: google___ads___googleads___v5___enums___ad_group_ad_rotation_mode_pb2___AdGroupAdRotationModeEnum.AdGroupAdRotationModeValue = ...
    base_ad_group: typing___Text = ...
    tracking_url_template: typing___Text = ...
    campaign: typing___Text = ...
    cpc_bid_micros: builtin___int = ...
    cpm_bid_micros: builtin___int = ...
    target_cpa_micros: builtin___int = ...
    cpv_bid_micros: builtin___int = ...
    target_cpm_micros: builtin___int = ...
    target_roas: builtin___float = ...
    percent_cpc_bid_micros: builtin___int = ...
    display_custom_bid_dimension: google___ads___googleads___v5___enums___targeting_dimension_pb2___TargetingDimensionEnum.TargetingDimensionValue = ...
    final_url_suffix: typing___Text = ...
    effective_target_cpa_micros: builtin___int = ...
    effective_target_cpa_source: google___ads___googleads___v5___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSourceValue = ...
    effective_target_roas: builtin___float = ...
    effective_target_roas_source: google___ads___googleads___v5___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSourceValue = ...
    labels: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    @property
    def url_custom_parameters(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v5___common___custom_parameter_pb2___CustomParameter
    ]: ...
    @property
    def explorer_auto_optimizer_setting(
        self,
    ) -> google___ads___googleads___v5___common___explorer_auto_optimizer_setting_pb2___ExplorerAutoOptimizerSetting: ...
    @property
    def targeting_setting(
        self,
    ) -> google___ads___googleads___v5___common___targeting_setting_pb2___TargetingSetting: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[builtin___int] = None,
        name: typing___Optional[typing___Text] = None,
        status: typing___Optional[
            google___ads___googleads___v5___enums___ad_group_status_pb2___AdGroupStatusEnum.AdGroupStatusValue
        ] = None,
        type: typing___Optional[
            google___ads___googleads___v5___enums___ad_group_type_pb2___AdGroupTypeEnum.AdGroupTypeValue
        ] = None,
        ad_rotation_mode: typing___Optional[
            google___ads___googleads___v5___enums___ad_group_ad_rotation_mode_pb2___AdGroupAdRotationModeEnum.AdGroupAdRotationModeValue
        ] = None,
        base_ad_group: typing___Optional[typing___Text] = None,
        tracking_url_template: typing___Optional[typing___Text] = None,
        url_custom_parameters: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v5___common___custom_parameter_pb2___CustomParameter
            ]
        ] = None,
        campaign: typing___Optional[typing___Text] = None,
        cpc_bid_micros: typing___Optional[builtin___int] = None,
        cpm_bid_micros: typing___Optional[builtin___int] = None,
        target_cpa_micros: typing___Optional[builtin___int] = None,
        cpv_bid_micros: typing___Optional[builtin___int] = None,
        target_cpm_micros: typing___Optional[builtin___int] = None,
        target_roas: typing___Optional[builtin___float] = None,
        percent_cpc_bid_micros: typing___Optional[builtin___int] = None,
        explorer_auto_optimizer_setting: typing___Optional[
            google___ads___googleads___v5___common___explorer_auto_optimizer_setting_pb2___ExplorerAutoOptimizerSetting
        ] = None,
        display_custom_bid_dimension: typing___Optional[
            google___ads___googleads___v5___enums___targeting_dimension_pb2___TargetingDimensionEnum.TargetingDimensionValue
        ] = None,
        final_url_suffix: typing___Optional[typing___Text] = None,
        targeting_setting: typing___Optional[
            google___ads___googleads___v5___common___targeting_setting_pb2___TargetingSetting
        ] = None,
        effective_target_cpa_micros: typing___Optional[builtin___int] = None,
        effective_target_cpa_source: typing___Optional[
            google___ads___googleads___v5___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSourceValue
        ] = None,
        effective_target_roas: typing___Optional[builtin___float] = None,
        effective_target_roas_source: typing___Optional[
            google___ads___googleads___v5___enums___bidding_source_pb2___BiddingSourceEnum.BiddingSourceValue
        ] = None,
        labels: typing___Optional[typing___Iterable[typing___Text]] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_base_ad_group",
            b"_base_ad_group",
            "_campaign",
            b"_campaign",
            "_cpc_bid_micros",
            b"_cpc_bid_micros",
            "_cpm_bid_micros",
            b"_cpm_bid_micros",
            "_cpv_bid_micros",
            b"_cpv_bid_micros",
            "_effective_target_cpa_micros",
            b"_effective_target_cpa_micros",
            "_effective_target_roas",
            b"_effective_target_roas",
            "_final_url_suffix",
            b"_final_url_suffix",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_percent_cpc_bid_micros",
            b"_percent_cpc_bid_micros",
            "_target_cpa_micros",
            b"_target_cpa_micros",
            "_target_cpm_micros",
            b"_target_cpm_micros",
            "_target_roas",
            b"_target_roas",
            "_tracking_url_template",
            b"_tracking_url_template",
            "base_ad_group",
            b"base_ad_group",
            "campaign",
            b"campaign",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "cpm_bid_micros",
            b"cpm_bid_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "effective_target_cpa_micros",
            b"effective_target_cpa_micros",
            "effective_target_roas",
            b"effective_target_roas",
            "explorer_auto_optimizer_setting",
            b"explorer_auto_optimizer_setting",
            "final_url_suffix",
            b"final_url_suffix",
            "id",
            b"id",
            "name",
            b"name",
            "percent_cpc_bid_micros",
            b"percent_cpc_bid_micros",
            "target_cpa_micros",
            b"target_cpa_micros",
            "target_cpm_micros",
            b"target_cpm_micros",
            "target_roas",
            b"target_roas",
            "targeting_setting",
            b"targeting_setting",
            "tracking_url_template",
            b"tracking_url_template",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_base_ad_group",
            b"_base_ad_group",
            "_campaign",
            b"_campaign",
            "_cpc_bid_micros",
            b"_cpc_bid_micros",
            "_cpm_bid_micros",
            b"_cpm_bid_micros",
            "_cpv_bid_micros",
            b"_cpv_bid_micros",
            "_effective_target_cpa_micros",
            b"_effective_target_cpa_micros",
            "_effective_target_roas",
            b"_effective_target_roas",
            "_final_url_suffix",
            b"_final_url_suffix",
            "_id",
            b"_id",
            "_name",
            b"_name",
            "_percent_cpc_bid_micros",
            b"_percent_cpc_bid_micros",
            "_target_cpa_micros",
            b"_target_cpa_micros",
            "_target_cpm_micros",
            b"_target_cpm_micros",
            "_target_roas",
            b"_target_roas",
            "_tracking_url_template",
            b"_tracking_url_template",
            "ad_rotation_mode",
            b"ad_rotation_mode",
            "base_ad_group",
            b"base_ad_group",
            "campaign",
            b"campaign",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "cpm_bid_micros",
            b"cpm_bid_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "display_custom_bid_dimension",
            b"display_custom_bid_dimension",
            "effective_target_cpa_micros",
            b"effective_target_cpa_micros",
            "effective_target_cpa_source",
            b"effective_target_cpa_source",
            "effective_target_roas",
            b"effective_target_roas",
            "effective_target_roas_source",
            b"effective_target_roas_source",
            "explorer_auto_optimizer_setting",
            b"explorer_auto_optimizer_setting",
            "final_url_suffix",
            b"final_url_suffix",
            "id",
            b"id",
            "labels",
            b"labels",
            "name",
            b"name",
            "percent_cpc_bid_micros",
            b"percent_cpc_bid_micros",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "target_cpa_micros",
            b"target_cpa_micros",
            "target_cpm_micros",
            b"target_cpm_micros",
            "target_roas",
            b"target_roas",
            "targeting_setting",
            b"targeting_setting",
            "tracking_url_template",
            b"tracking_url_template",
            "type",
            b"type",
            "url_custom_parameters",
            b"url_custom_parameters",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_base_ad_group", b"_base_ad_group"],
    ) -> typing_extensions___Literal["base_ad_group"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_campaign", b"_campaign"]
    ) -> typing_extensions___Literal["campaign"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_cpc_bid_micros", b"_cpc_bid_micros"],
    ) -> typing_extensions___Literal["cpc_bid_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_cpm_bid_micros", b"_cpm_bid_micros"],
    ) -> typing_extensions___Literal["cpm_bid_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_cpv_bid_micros", b"_cpv_bid_micros"],
    ) -> typing_extensions___Literal["cpv_bid_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_effective_target_cpa_micros", b"_effective_target_cpa_micros"
        ],
    ) -> typing_extensions___Literal["effective_target_cpa_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_effective_target_roas", b"_effective_target_roas"
        ],
    ) -> typing_extensions___Literal["effective_target_roas"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_final_url_suffix", b"_final_url_suffix"
        ],
    ) -> typing_extensions___Literal["final_url_suffix"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_id", b"_id"]
    ) -> typing_extensions___Literal["id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_name", b"_name"]
    ) -> typing_extensions___Literal["name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_percent_cpc_bid_micros", b"_percent_cpc_bid_micros"
        ],
    ) -> typing_extensions___Literal["percent_cpc_bid_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_target_cpa_micros", b"_target_cpa_micros"
        ],
    ) -> typing_extensions___Literal["target_cpa_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_target_cpm_micros", b"_target_cpm_micros"
        ],
    ) -> typing_extensions___Literal["target_cpm_micros"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_target_roas", b"_target_roas"]
    ) -> typing_extensions___Literal["target_roas"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_tracking_url_template", b"_tracking_url_template"
        ],
    ) -> typing_extensions___Literal["tracking_url_template"]: ...

type___AdGroup = AdGroup



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AccountBudgetProposalStatusEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AccountBudgetProposalStatusValue = typing___NewType(
        "AccountBudgetProposalStatusValue", builtin___int
    )
    type___AccountBudgetProposalStatusValue = AccountBudgetProposalStatusValue
    AccountBudgetProposalStatus: _AccountBudgetProposalStatus
    class _AccountBudgetProposalStatus(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 0
        )
        UNKNOWN = typing___cast(
            AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 1
        )
        PENDING = typing___cast(
            AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 2
        )
        APPROVED_HELD = typing___cast(
            AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 3
        )
        APPROVED = typing___cast(
            AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 4
        )
        CANCELLED = typing___cast(
            AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 5
        )
        REJECTED = typing___cast(
            AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 6
        )
    UNSPECIFIED = typing___cast(
        AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 0
    )
    UNKNOWN = typing___cast(
        AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 1
    )
    PENDING = typing___cast(
        AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 2
    )
    APPROVED_HELD = typing___cast(
        AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 3
    )
    APPROVED = typing___cast(
        AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 4
    )
    CANCELLED = typing___cast(
        AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 5
    )
    REJECTED = typing___cast(
        AccountBudgetProposalStatusEnum.AccountBudgetProposalStatusValue, 6
    )
    type___AccountBudgetProposalStatus = AccountBudgetProposalStatus
    def __init__(self,) -> None: ...

type___AccountBudgetProposalStatusEnum = AccountBudgetProposalStatusEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ConversionActionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ConversionActionTypeValue = typing___NewType(
        "ConversionActionTypeValue", builtin___int
    )
    type___ConversionActionTypeValue = ConversionActionTypeValue
    ConversionActionType: _ConversionActionType
    class _ConversionActionType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ConversionActionTypeEnum.ConversionActionTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 0
        )
        UNKNOWN = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 1)
        AD_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 2)
        CLICK_TO_CALL = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 3
        )
        GOOGLE_PLAY_DOWNLOAD = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 4
        )
        GOOGLE_PLAY_IN_APP_PURCHASE = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 5
        )
        UPLOAD_CALLS = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 6
        )
        UPLOAD_CLICKS = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 7
        )
        WEBPAGE = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 8)
        WEBSITE_CALL = typing___cast(
            ConversionActionTypeEnum.ConversionActionTypeValue, 9
        )
    UNSPECIFIED = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 0)
    UNKNOWN = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 1)
    AD_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 2)
    CLICK_TO_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 3)
    GOOGLE_PLAY_DOWNLOAD = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 4
    )
    GOOGLE_PLAY_IN_APP_PURCHASE = typing___cast(
        ConversionActionTypeEnum.ConversionActionTypeValue, 5
    )
    UPLOAD_CALLS = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 6)
    UPLOAD_CLICKS = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 7)
    WEBPAGE = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 8)
    WEBSITE_CALL = typing___cast(ConversionActionTypeEnum.ConversionActionTypeValue, 9)
    type___ConversionActionType = ConversionActionType
    def __init__(self,) -> None: ...

type___ConversionActionTypeEnum = ConversionActionTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class SimulationTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    SimulationTypeValue = typing___NewType("SimulationTypeValue", builtin___int)
    type___SimulationTypeValue = SimulationTypeValue
    SimulationType: _SimulationType
    class _SimulationType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            SimulationTypeEnum.SimulationTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(SimulationTypeEnum.SimulationTypeValue, 0)
        UNKNOWN = typing___cast(SimulationTypeEnum.SimulationTypeValue, 1)
        CPC_BID = typing___cast(SimulationTypeEnum.SimulationTypeValue, 2)
        CPV_BID = typing___cast(SimulationTypeEnum.SimulationTypeValue, 3)
        TARGET_CPA = typing___cast(SimulationTypeEnum.SimulationTypeValue, 4)
        BID_MODIFIER = typing___cast(SimulationTypeEnum.SimulationTypeValue, 5)
    UNSPECIFIED = typing___cast(SimulationTypeEnum.SimulationTypeValue, 0)
    UNKNOWN = typing___cast(SimulationTypeEnum.SimulationTypeValue, 1)
    CPC_BID = typing___cast(SimulationTypeEnum.SimulationTypeValue, 2)
    CPV_BID = typing___cast(SimulationTypeEnum.SimulationTypeValue, 3)
    TARGET_CPA = typing___cast(SimulationTypeEnum.SimulationTypeValue, 4)
    BID_MODIFIER = typing___cast(SimulationTypeEnum.SimulationTypeValue, 5)
    type___SimulationType = SimulationType
    def __init__(self,) -> None: ...

type___SimulationTypeEnum = SimulationTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    NewType as typing___NewType,
    Optional as typing___Optional,
    Text as typing___Text,
    cast as typing___cast,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.enums.affiliate_location_feed_relationship_type_pb2 import (
    AffiliateLocationFeedRelationshipTypeEnum as google___ads___googleads___v4___enums___affiliate_location_feed_relationship_type_pb2___AffiliateLocationFeedRelationshipTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.feed_attribute_type_pb2 import (
    FeedAttributeTypeEnum as google___ads___googleads___v4___enums___feed_attribute_type_pb2___FeedAttributeTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.feed_origin_pb2 import (
    FeedOriginEnum as google___ads___googleads___v4___enums___feed_origin_pb2___FeedOriginEnum,
)
from google.ads.google_ads.v4.proto.enums.feed_status_pb2 import (
    FeedStatusEnum as google___ads___googleads___v4___enums___feed_status_pb2___FeedStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Feed(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class PlacesLocationFeedData(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        class OAuthInfo(google___protobuf___message___Message):
            DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
            @property
            def http_method(self) -> google___protobuf___wrappers_pb2___StringValue: ...
            @property
            def http_request_url(
                self,
            ) -> google___protobuf___wrappers_pb2___StringValue: ...
            @property
            def http_authorization_header(
                self,
            ) -> google___protobuf___wrappers_pb2___StringValue: ...
            def __init__(
                self,
                *,
                http_method: typing___Optional[
                    google___protobuf___wrappers_pb2___StringValue
                ] = None,
                http_request_url: typing___Optional[
                    google___protobuf___wrappers_pb2___StringValue
                ] = None,
                http_authorization_header: typing___Optional[
                    google___protobuf___wrappers_pb2___StringValue
                ] = None,
            ) -> None: ...
            def HasField(
                self,
                field_name: typing_extensions___Literal[
                    "http_authorization_header",
                    b"http_authorization_header",
                    "http_method",
                    b"http_method",
                    "http_request_url",
                    b"http_request_url",
                ],
            ) -> builtin___bool: ...
            def ClearField(
                self,
                field_name: typing_extensions___Literal[
                    "http_authorization_header",
                    b"http_authorization_header",
                    "http_method",
                    b"http_method",
                    "http_request_url",
                    b"http_request_url",
                ],
            ) -> None: ...
        type___OAuthInfo = OAuthInfo
        @property
        def oauth_info(self) -> type___Feed.PlacesLocationFeedData.OAuthInfo: ...
        @property
        def email_address(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def business_account_id(
            self,
        ) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def business_name_filter(
            self,
        ) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def category_filters(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            google___protobuf___wrappers_pb2___StringValue
        ]: ...
        @property
        def label_filters(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            google___protobuf___wrappers_pb2___StringValue
        ]: ...
        def __init__(
            self,
            *,
            oauth_info: typing___Optional[
                type___Feed.PlacesLocationFeedData.OAuthInfo
            ] = None,
            email_address: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            business_account_id: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            business_name_filter: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            category_filters: typing___Optional[
                typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
            ] = None,
            label_filters: typing___Optional[
                typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "business_account_id",
                b"business_account_id",
                "business_name_filter",
                b"business_name_filter",
                "email_address",
                b"email_address",
                "oauth_info",
                b"oauth_info",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "business_account_id",
                b"business_account_id",
                "business_name_filter",
                b"business_name_filter",
                "category_filters",
                b"category_filters",
                "email_address",
                b"email_address",
                "label_filters",
                b"label_filters",
                "oauth_info",
                b"oauth_info",
            ],
        ) -> None: ...
    type___PlacesLocationFeedData = PlacesLocationFeedData
    class AffiliateLocationFeedData(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        relationship_type: google___ads___googleads___v4___enums___affiliate_location_feed_relationship_type_pb2___AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeValue = ...
        @property
        def chain_ids(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            google___protobuf___wrappers_pb2___Int64Value
        ]: ...
        def __init__(
            self,
            *,
            chain_ids: typing___Optional[
                typing___Iterable[google___protobuf___wrappers_pb2___Int64Value]
            ] = None,
            relationship_type: typing___Optional[
                google___ads___googleads___v4___enums___affiliate_location_feed_relationship_type_pb2___AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipTypeValue
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "chain_ids", b"chain_ids", "relationship_type", b"relationship_type"
            ],
        ) -> None: ...
    type___AffiliateLocationFeedData = AffiliateLocationFeedData

    resource_name: typing___Text = ...
    origin: google___ads___googleads___v4___enums___feed_origin_pb2___FeedOriginEnum.FeedOriginValue = ...
    status: google___ads___googleads___v4___enums___feed_status_pb2___FeedStatusEnum.FeedStatusValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def attributes(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___FeedAttribute
    ]: ...
    @property
    def attribute_operations(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___FeedAttributeOperation
    ]: ...
    @property
    def places_location_feed_data(self) -> type___Feed.PlacesLocationFeedData: ...
    @property
    def affiliate_location_feed_data(self) -> type___Feed.AffiliateLocationFeedData: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        attributes: typing___Optional[typing___Iterable[type___FeedAttribute]] = None,
        attribute_operations: typing___Optional[
            typing___Iterable[type___FeedAttributeOperation]
        ] = None,
        origin: typing___Optional[
            google___ads___googleads___v4___enums___feed_origin_pb2___FeedOriginEnum.FeedOriginValue
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v4___enums___feed_status_pb2___FeedStatusEnum.FeedStatusValue
        ] = None,
        places_location_feed_data: typing___Optional[
            type___Feed.PlacesLocationFeedData
        ] = None,
        affiliate_location_feed_data: typing___Optional[
            type___Feed.AffiliateLocationFeedData
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "affiliate_location_feed_data",
            b"affiliate_location_feed_data",
            "id",
            b"id",
            "name",
            b"name",
            "places_location_feed_data",
            b"places_location_feed_data",
            "system_feed_generation_data",
            b"system_feed_generation_data",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "affiliate_location_feed_data",
            b"affiliate_location_feed_data",
            "attribute_operations",
            b"attribute_operations",
            "attributes",
            b"attributes",
            "id",
            b"id",
            "name",
            b"name",
            "origin",
            b"origin",
            "places_location_feed_data",
            b"places_location_feed_data",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "system_feed_generation_data",
            b"system_feed_generation_data",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "system_feed_generation_data", b"system_feed_generation_data"
        ],
    ) -> typing_extensions___Literal[
        "places_location_feed_data", "affiliate_location_feed_data"
    ]: ...

type___Feed = Feed

class FeedAttribute(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type: google___ads___googleads___v4___enums___feed_attribute_type_pb2___FeedAttributeTypeEnum.FeedAttributeTypeValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def is_part_of_key(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    def __init__(
        self,
        *,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        type: typing___Optional[
            google___ads___googleads___v4___enums___feed_attribute_type_pb2___FeedAttributeTypeEnum.FeedAttributeTypeValue
        ] = None,
        is_part_of_key: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "id", b"id", "is_part_of_key", b"is_part_of_key", "name", b"name"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "id",
            b"id",
            "is_part_of_key",
            b"is_part_of_key",
            "name",
            b"name",
            "type",
            b"type",
        ],
    ) -> None: ...

type___FeedAttribute = FeedAttribute

class FeedAttributeOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    OperatorValue = typing___NewType("OperatorValue", builtin___int)
    type___OperatorValue = OperatorValue
    Operator: _Operator
    class _Operator(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedAttributeOperation.OperatorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(FeedAttributeOperation.OperatorValue, 0)
        UNKNOWN = typing___cast(FeedAttributeOperation.OperatorValue, 1)
        ADD = typing___cast(FeedAttributeOperation.OperatorValue, 2)
    UNSPECIFIED = typing___cast(FeedAttributeOperation.OperatorValue, 0)
    UNKNOWN = typing___cast(FeedAttributeOperation.OperatorValue, 1)
    ADD = typing___cast(FeedAttributeOperation.OperatorValue, 2)
    type___Operator = Operator

    operator: type___FeedAttributeOperation.OperatorValue = ...
    @property
    def value(self) -> type___FeedAttribute: ...
    def __init__(
        self,
        *,
        operator: typing___Optional[type___FeedAttributeOperation.OperatorValue] = None,
        value: typing___Optional[type___FeedAttribute] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["value", b"value"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "operator", b"operator", "value", b"value"
        ],
    ) -> None: ...

type___FeedAttributeOperation = FeedAttributeOperation



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.geo_targeting_type_pb2 import (
    GeoTargetingTypeEnum as google___ads___googleads___v5___enums___geo_targeting_type_pb2___GeoTargetingTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GeographicView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    location_type: google___ads___googleads___v5___enums___geo_targeting_type_pb2___GeoTargetingTypeEnum.GeoTargetingTypeValue = ...
    country_criterion_id: builtin___int = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        location_type: typing___Optional[
            google___ads___googleads___v5___enums___geo_targeting_type_pb2___GeoTargetingTypeEnum.GeoTargetingTypeValue
        ] = None,
        country_criterion_id: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_country_criterion_id",
            b"_country_criterion_id",
            "country_criterion_id",
            b"country_criterion_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_country_criterion_id",
            b"_country_criterion_id",
            "country_criterion_id",
            b"country_criterion_id",
            "location_type",
            b"location_type",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_country_criterion_id", b"_country_criterion_id"
        ],
    ) -> typing_extensions___Literal["country_criterion_id"]: ...

type___GeographicView = GeographicView



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.common.policy_pb2 import (
    PolicyTopicEntry as google___ads___googleads___v3___common___policy_pb2___PolicyTopicEntry,
)
from google.ads.google_ads.v3.proto.enums.asset_field_type_pb2 import (
    AssetFieldTypeEnum as google___ads___googleads___v3___enums___asset_field_type_pb2___AssetFieldTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.asset_performance_label_pb2 import (
    AssetPerformanceLabelEnum as google___ads___googleads___v3___enums___asset_performance_label_pb2___AssetPerformanceLabelEnum,
)
from google.ads.google_ads.v3.proto.enums.policy_approval_status_pb2 import (
    PolicyApprovalStatusEnum as google___ads___googleads___v3___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum,
)
from google.ads.google_ads.v3.proto.enums.policy_review_status_pb2 import (
    PolicyReviewStatusEnum as google___ads___googleads___v3___enums___policy_review_status_pb2___PolicyReviewStatusEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdGroupAdAssetView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    field_type: google___ads___googleads___v3___enums___asset_field_type_pb2___AssetFieldTypeEnum.AssetFieldTypeValue = ...
    performance_label: google___ads___googleads___v3___enums___asset_performance_label_pb2___AssetPerformanceLabelEnum.AssetPerformanceLabelValue = ...
    @property
    def ad_group_ad(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def asset(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def policy_summary(self) -> type___AdGroupAdAssetPolicySummary: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        ad_group_ad: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        asset: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        field_type: typing___Optional[
            google___ads___googleads___v3___enums___asset_field_type_pb2___AssetFieldTypeEnum.AssetFieldTypeValue
        ] = None,
        policy_summary: typing___Optional[type___AdGroupAdAssetPolicySummary] = None,
        performance_label: typing___Optional[
            google___ads___googleads___v3___enums___asset_performance_label_pb2___AssetPerformanceLabelEnum.AssetPerformanceLabelValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group_ad",
            b"ad_group_ad",
            "asset",
            b"asset",
            "policy_summary",
            b"policy_summary",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group_ad",
            b"ad_group_ad",
            "asset",
            b"asset",
            "field_type",
            b"field_type",
            "performance_label",
            b"performance_label",
            "policy_summary",
            b"policy_summary",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

type___AdGroupAdAssetView = AdGroupAdAssetView

class AdGroupAdAssetPolicySummary(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    review_status: google___ads___googleads___v3___enums___policy_review_status_pb2___PolicyReviewStatusEnum.PolicyReviewStatusValue = ...
    approval_status: google___ads___googleads___v3___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum.PolicyApprovalStatusValue = ...
    @property
    def policy_topic_entries(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v3___common___policy_pb2___PolicyTopicEntry
    ]: ...
    def __init__(
        self,
        *,
        policy_topic_entries: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___common___policy_pb2___PolicyTopicEntry
            ]
        ] = None,
        review_status: typing___Optional[
            google___ads___googleads___v3___enums___policy_review_status_pb2___PolicyReviewStatusEnum.PolicyReviewStatusValue
        ] = None,
        approval_status: typing___Optional[
            google___ads___googleads___v3___enums___policy_approval_status_pb2___PolicyApprovalStatusEnum.PolicyApprovalStatusValue
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "approval_status",
            b"approval_status",
            "policy_topic_entries",
            b"policy_topic_entries",
            "review_status",
            b"review_status",
        ],
    ) -> None: ...

type___AdGroupAdAssetPolicySummary = AdGroupAdAssetPolicySummary



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordPlanNetworkEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    KeywordPlanNetworkValue = typing___NewType("KeywordPlanNetworkValue", builtin___int)
    type___KeywordPlanNetworkValue = KeywordPlanNetworkValue
    KeywordPlanNetwork: _KeywordPlanNetwork
    class _KeywordPlanNetwork(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            KeywordPlanNetworkEnum.KeywordPlanNetworkValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(KeywordPlanNetworkEnum.KeywordPlanNetworkValue, 0)
        UNKNOWN = typing___cast(KeywordPlanNetworkEnum.KeywordPlanNetworkValue, 1)
        GOOGLE_SEARCH = typing___cast(KeywordPlanNetworkEnum.KeywordPlanNetworkValue, 2)
        GOOGLE_SEARCH_AND_PARTNERS = typing___cast(
            KeywordPlanNetworkEnum.KeywordPlanNetworkValue, 3
        )
    UNSPECIFIED = typing___cast(KeywordPlanNetworkEnum.KeywordPlanNetworkValue, 0)
    UNKNOWN = typing___cast(KeywordPlanNetworkEnum.KeywordPlanNetworkValue, 1)
    GOOGLE_SEARCH = typing___cast(KeywordPlanNetworkEnum.KeywordPlanNetworkValue, 2)
    GOOGLE_SEARCH_AND_PARTNERS = typing___cast(
        KeywordPlanNetworkEnum.KeywordPlanNetworkValue, 3
    )
    type___KeywordPlanNetwork = KeywordPlanNetwork
    def __init__(self,) -> None: ...

type___KeywordPlanNetworkEnum = KeywordPlanNetworkEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.enums.custom_interest_member_type_pb2 import (
    CustomInterestMemberTypeEnum as google___ads___googleads___v4___enums___custom_interest_member_type_pb2___CustomInterestMemberTypeEnum,
)
from google.ads.google_ads.v4.proto.enums.custom_interest_status_pb2 import (
    CustomInterestStatusEnum as google___ads___googleads___v4___enums___custom_interest_status_pb2___CustomInterestStatusEnum,
)
from google.ads.google_ads.v4.proto.enums.custom_interest_type_pb2 import (
    CustomInterestTypeEnum as google___ads___googleads___v4___enums___custom_interest_type_pb2___CustomInterestTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomInterest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    status: google___ads___googleads___v4___enums___custom_interest_status_pb2___CustomInterestStatusEnum.CustomInterestStatusValue = ...
    type: google___ads___googleads___v4___enums___custom_interest_type_pb2___CustomInterestTypeEnum.CustomInterestTypeValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def description(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def members(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___CustomInterestMember
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        status: typing___Optional[
            google___ads___googleads___v4___enums___custom_interest_status_pb2___CustomInterestStatusEnum.CustomInterestStatusValue
        ] = None,
        name: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        type: typing___Optional[
            google___ads___googleads___v4___enums___custom_interest_type_pb2___CustomInterestTypeEnum.CustomInterestTypeValue
        ] = None,
        description: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        members: typing___Optional[
            typing___Iterable[type___CustomInterestMember]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "description", b"description", "id", b"id", "name", b"name"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "description",
            b"description",
            "id",
            b"id",
            "members",
            b"members",
            "name",
            b"name",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "type",
            b"type",
        ],
    ) -> None: ...

type___CustomInterest = CustomInterest

class CustomInterestMember(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    member_type: google___ads___googleads___v4___enums___custom_interest_member_type_pb2___CustomInterestMemberTypeEnum.CustomInterestMemberTypeValue = ...
    @property
    def parameter(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        member_type: typing___Optional[
            google___ads___googleads___v4___enums___custom_interest_member_type_pb2___CustomInterestMemberTypeEnum.CustomInterestMemberTypeValue
        ] = None,
        parameter: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["parameter", b"parameter"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "member_type", b"member_type", "parameter", b"parameter"
        ],
    ) -> None: ...

type___CustomInterestMember = CustomInterestMember



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class LocationPlaceholderFieldEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    LocationPlaceholderFieldValue = typing___NewType(
        "LocationPlaceholderFieldValue", builtin___int
    )
    type___LocationPlaceholderFieldValue = LocationPlaceholderFieldValue
    LocationPlaceholderField: _LocationPlaceholderField
    class _LocationPlaceholderField(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 0
        )
        UNKNOWN = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 1
        )
        BUSINESS_NAME = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 2
        )
        ADDRESS_LINE_1 = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 3
        )
        ADDRESS_LINE_2 = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 4
        )
        CITY = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 5
        )
        PROVINCE = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 6
        )
        POSTAL_CODE = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 7
        )
        COUNTRY_CODE = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 8
        )
        PHONE_NUMBER = typing___cast(
            LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 9
        )
    UNSPECIFIED = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 0
    )
    UNKNOWN = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 1
    )
    BUSINESS_NAME = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 2
    )
    ADDRESS_LINE_1 = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 3
    )
    ADDRESS_LINE_2 = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 4
    )
    CITY = typing___cast(LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 5)
    PROVINCE = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 6
    )
    POSTAL_CODE = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 7
    )
    COUNTRY_CODE = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 8
    )
    PHONE_NUMBER = typing___cast(
        LocationPlaceholderFieldEnum.LocationPlaceholderFieldValue, 9
    )
    type___LocationPlaceholderField = LocationPlaceholderField
    def __init__(self,) -> None: ...

type___LocationPlaceholderFieldEnum = LocationPlaceholderFieldEnum



from typing import Any

class ProductBiddingCategoryConstantServiceStub:
    GetProductBiddingCategoryConstant: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ProductBiddingCategoryConstantServiceServicer:
    def GetProductBiddingCategoryConstant(self, request: Any, context: Any) -> None: ...

def add_ProductBiddingCategoryConstantServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    FloatValue as google___protobuf___wrappers_pb2___FloatValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.common.criteria_pb2 import (
    AdScheduleInfo as google___ads___googleads___v4___common___criteria_pb2___AdScheduleInfo,
    AgeRangeInfo as google___ads___googleads___v4___common___criteria_pb2___AgeRangeInfo,
    CarrierInfo as google___ads___googleads___v4___common___criteria_pb2___CarrierInfo,
    ContentLabelInfo as google___ads___googleads___v4___common___criteria_pb2___ContentLabelInfo,
    CustomAffinityInfo as google___ads___googleads___v4___common___criteria_pb2___CustomAffinityInfo,
    DeviceInfo as google___ads___googleads___v4___common___criteria_pb2___DeviceInfo,
    GenderInfo as google___ads___googleads___v4___common___criteria_pb2___GenderInfo,
    IncomeRangeInfo as google___ads___googleads___v4___common___criteria_pb2___IncomeRangeInfo,
    IpBlockInfo as google___ads___googleads___v4___common___criteria_pb2___IpBlockInfo,
    KeywordInfo as google___ads___googleads___v4___common___criteria_pb2___KeywordInfo,
    LanguageInfo as google___ads___googleads___v4___common___criteria_pb2___LanguageInfo,
    ListingScopeInfo as google___ads___googleads___v4___common___criteria_pb2___ListingScopeInfo,
    LocationGroupInfo as google___ads___googleads___v4___common___criteria_pb2___LocationGroupInfo,
    LocationInfo as google___ads___googleads___v4___common___criteria_pb2___LocationInfo,
    MobileAppCategoryInfo as google___ads___googleads___v4___common___criteria_pb2___MobileAppCategoryInfo,
    MobileApplicationInfo as google___ads___googleads___v4___common___criteria_pb2___MobileApplicationInfo,
    MobileDeviceInfo as google___ads___googleads___v4___common___criteria_pb2___MobileDeviceInfo,
    OperatingSystemVersionInfo as google___ads___googleads___v4___common___criteria_pb2___OperatingSystemVersionInfo,
    ParentalStatusInfo as google___ads___googleads___v4___common___criteria_pb2___ParentalStatusInfo,
    PlacementInfo as google___ads___googleads___v4___common___criteria_pb2___PlacementInfo,
    ProximityInfo as google___ads___googleads___v4___common___criteria_pb2___ProximityInfo,
    TopicInfo as google___ads___googleads___v4___common___criteria_pb2___TopicInfo,
    UserInterestInfo as google___ads___googleads___v4___common___criteria_pb2___UserInterestInfo,
    UserListInfo as google___ads___googleads___v4___common___criteria_pb2___UserListInfo,
    WebpageInfo as google___ads___googleads___v4___common___criteria_pb2___WebpageInfo,
    YouTubeChannelInfo as google___ads___googleads___v4___common___criteria_pb2___YouTubeChannelInfo,
    YouTubeVideoInfo as google___ads___googleads___v4___common___criteria_pb2___YouTubeVideoInfo,
)
from google.ads.google_ads.v4.proto.enums.campaign_criterion_status_pb2 import (
    CampaignCriterionStatusEnum as google___ads___googleads___v4___enums___campaign_criterion_status_pb2___CampaignCriterionStatusEnum,
)
from google.ads.google_ads.v4.proto.enums.criterion_type_pb2 import (
    CriterionTypeEnum as google___ads___googleads___v4___enums___criterion_type_pb2___CriterionTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignCriterion(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    type: google___ads___googleads___v4___enums___criterion_type_pb2___CriterionTypeEnum.CriterionTypeValue = ...
    status: google___ads___googleads___v4___enums___campaign_criterion_status_pb2___CampaignCriterionStatusEnum.CampaignCriterionStatusValue = ...
    @property
    def campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def criterion_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def bid_modifier(self) -> google___protobuf___wrappers_pb2___FloatValue: ...
    @property
    def negative(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def keyword(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___KeywordInfo: ...
    @property
    def placement(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___PlacementInfo: ...
    @property
    def mobile_app_category(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___MobileAppCategoryInfo: ...
    @property
    def mobile_application(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___MobileApplicationInfo: ...
    @property
    def location(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___LocationInfo: ...
    @property
    def device(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___DeviceInfo: ...
    @property
    def ad_schedule(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___AdScheduleInfo: ...
    @property
    def age_range(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___AgeRangeInfo: ...
    @property
    def gender(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___GenderInfo: ...
    @property
    def income_range(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___IncomeRangeInfo: ...
    @property
    def parental_status(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___ParentalStatusInfo: ...
    @property
    def user_list(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___UserListInfo: ...
    @property
    def youtube_video(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___YouTubeVideoInfo: ...
    @property
    def youtube_channel(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___YouTubeChannelInfo: ...
    @property
    def proximity(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___ProximityInfo: ...
    @property
    def topic(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___TopicInfo: ...
    @property
    def listing_scope(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___ListingScopeInfo: ...
    @property
    def language(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___LanguageInfo: ...
    @property
    def ip_block(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___IpBlockInfo: ...
    @property
    def content_label(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___ContentLabelInfo: ...
    @property
    def carrier(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___CarrierInfo: ...
    @property
    def user_interest(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___UserInterestInfo: ...
    @property
    def webpage(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___WebpageInfo: ...
    @property
    def operating_system_version(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___OperatingSystemVersionInfo: ...
    @property
    def mobile_device(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___MobileDeviceInfo: ...
    @property
    def location_group(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___LocationGroupInfo: ...
    @property
    def custom_affinity(
        self,
    ) -> google___ads___googleads___v4___common___criteria_pb2___CustomAffinityInfo: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        campaign: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        criterion_id: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        bid_modifier: typing___Optional[
            google___protobuf___wrappers_pb2___FloatValue
        ] = None,
        negative: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        type: typing___Optional[
            google___ads___googleads___v4___enums___criterion_type_pb2___CriterionTypeEnum.CriterionTypeValue
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v4___enums___campaign_criterion_status_pb2___CampaignCriterionStatusEnum.CampaignCriterionStatusValue
        ] = None,
        keyword: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___KeywordInfo
        ] = None,
        placement: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___PlacementInfo
        ] = None,
        mobile_app_category: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___MobileAppCategoryInfo
        ] = None,
        mobile_application: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___MobileApplicationInfo
        ] = None,
        location: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___LocationInfo
        ] = None,
        device: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___DeviceInfo
        ] = None,
        ad_schedule: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___AdScheduleInfo
        ] = None,
        age_range: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___AgeRangeInfo
        ] = None,
        gender: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___GenderInfo
        ] = None,
        income_range: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___IncomeRangeInfo
        ] = None,
        parental_status: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___ParentalStatusInfo
        ] = None,
        user_list: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___UserListInfo
        ] = None,
        youtube_video: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___YouTubeVideoInfo
        ] = None,
        youtube_channel: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___YouTubeChannelInfo
        ] = None,
        proximity: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___ProximityInfo
        ] = None,
        topic: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___TopicInfo
        ] = None,
        listing_scope: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___ListingScopeInfo
        ] = None,
        language: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___LanguageInfo
        ] = None,
        ip_block: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___IpBlockInfo
        ] = None,
        content_label: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___ContentLabelInfo
        ] = None,
        carrier: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___CarrierInfo
        ] = None,
        user_interest: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___UserInterestInfo
        ] = None,
        webpage: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___WebpageInfo
        ] = None,
        operating_system_version: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___OperatingSystemVersionInfo
        ] = None,
        mobile_device: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___MobileDeviceInfo
        ] = None,
        location_group: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___LocationGroupInfo
        ] = None,
        custom_affinity: typing___Optional[
            google___ads___googleads___v4___common___criteria_pb2___CustomAffinityInfo
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "ad_schedule",
            b"ad_schedule",
            "age_range",
            b"age_range",
            "bid_modifier",
            b"bid_modifier",
            "campaign",
            b"campaign",
            "carrier",
            b"carrier",
            "content_label",
            b"content_label",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "custom_affinity",
            b"custom_affinity",
            "device",
            b"device",
            "gender",
            b"gender",
            "income_range",
            b"income_range",
            "ip_block",
            b"ip_block",
            "keyword",
            b"keyword",
            "language",
            b"language",
            "listing_scope",
            b"listing_scope",
            "location",
            b"location",
            "location_group",
            b"location_group",
            "mobile_app_category",
            b"mobile_app_category",
            "mobile_application",
            b"mobile_application",
            "mobile_device",
            b"mobile_device",
            "negative",
            b"negative",
            "operating_system_version",
            b"operating_system_version",
            "parental_status",
            b"parental_status",
            "placement",
            b"placement",
            "proximity",
            b"proximity",
            "topic",
            b"topic",
            "user_interest",
            b"user_interest",
            "user_list",
            b"user_list",
            "webpage",
            b"webpage",
            "youtube_channel",
            b"youtube_channel",
            "youtube_video",
            b"youtube_video",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_schedule",
            b"ad_schedule",
            "age_range",
            b"age_range",
            "bid_modifier",
            b"bid_modifier",
            "campaign",
            b"campaign",
            "carrier",
            b"carrier",
            "content_label",
            b"content_label",
            "criterion",
            b"criterion",
            "criterion_id",
            b"criterion_id",
            "custom_affinity",
            b"custom_affinity",
            "device",
            b"device",
            "gender",
            b"gender",
            "income_range",
            b"income_range",
            "ip_block",
            b"ip_block",
            "keyword",
            b"keyword",
            "language",
            b"language",
            "listing_scope",
            b"listing_scope",
            "location",
            b"location",
            "location_group",
            b"location_group",
            "mobile_app_category",
            b"mobile_app_category",
            "mobile_application",
            b"mobile_application",
            "mobile_device",
            b"mobile_device",
            "negative",
            b"negative",
            "operating_system_version",
            b"operating_system_version",
            "parental_status",
            b"parental_status",
            "placement",
            b"placement",
            "proximity",
            b"proximity",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "topic",
            b"topic",
            "type",
            b"type",
            "user_interest",
            b"user_interest",
            "user_list",
            b"user_list",
            "webpage",
            b"webpage",
            "youtube_channel",
            b"youtube_channel",
            "youtube_video",
            b"youtube_video",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["criterion", b"criterion"]
    ) -> typing_extensions___Literal[
        "keyword",
        "placement",
        "mobile_app_category",
        "mobile_application",
        "location",
        "device",
        "ad_schedule",
        "age_range",
        "gender",
        "income_range",
        "parental_status",
        "user_list",
        "youtube_video",
        "youtube_channel",
        "proximity",
        "topic",
        "listing_scope",
        "language",
        "ip_block",
        "content_label",
        "carrier",
        "user_interest",
        "webpage",
        "operating_system_version",
        "mobile_device",
        "location_group",
        "custom_affinity",
    ]: ...

type___CampaignCriterion = CampaignCriterion



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.enums.budget_delivery_method_pb2 import (
    BudgetDeliveryMethodEnum as google___ads___googleads___v3___enums___budget_delivery_method_pb2___BudgetDeliveryMethodEnum,
)
from google.ads.google_ads.v3.proto.enums.budget_period_pb2 import (
    BudgetPeriodEnum as google___ads___googleads___v3___enums___budget_period_pb2___BudgetPeriodEnum,
)
from google.ads.google_ads.v3.proto.enums.budget_status_pb2 import (
    BudgetStatusEnum as google___ads___googleads___v3___enums___budget_status_pb2___BudgetStatusEnum,
)
from google.ads.google_ads.v3.proto.enums.budget_type_pb2 import (
    BudgetTypeEnum as google___ads___googleads___v3___enums___budget_type_pb2___BudgetTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CampaignBudget(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    status: google___ads___googleads___v3___enums___budget_status_pb2___BudgetStatusEnum.BudgetStatusValue = ...
    delivery_method: google___ads___googleads___v3___enums___budget_delivery_method_pb2___BudgetDeliveryMethodEnum.BudgetDeliveryMethodValue = ...
    period: google___ads___googleads___v3___enums___budget_period_pb2___BudgetPeriodEnum.BudgetPeriodValue = ...
    type: google___ads___googleads___v3___enums___budget_type_pb2___BudgetTypeEnum.BudgetTypeValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def total_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def explicitly_shared(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def reference_count(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def has_recommended_budget(
        self,
    ) -> google___protobuf___wrappers_pb2___BoolValue: ...
    @property
    def recommended_budget_amount_micros(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def recommended_budget_estimated_change_weekly_clicks(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def recommended_budget_estimated_change_weekly_cost_micros(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def recommended_budget_estimated_change_weekly_interactions(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def recommended_budget_estimated_change_weekly_views(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        amount_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        total_amount_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v3___enums___budget_status_pb2___BudgetStatusEnum.BudgetStatusValue
        ] = None,
        delivery_method: typing___Optional[
            google___ads___googleads___v3___enums___budget_delivery_method_pb2___BudgetDeliveryMethodEnum.BudgetDeliveryMethodValue
        ] = None,
        explicitly_shared: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        reference_count: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        has_recommended_budget: typing___Optional[
            google___protobuf___wrappers_pb2___BoolValue
        ] = None,
        recommended_budget_amount_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        period: typing___Optional[
            google___ads___googleads___v3___enums___budget_period_pb2___BudgetPeriodEnum.BudgetPeriodValue
        ] = None,
        recommended_budget_estimated_change_weekly_clicks: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        recommended_budget_estimated_change_weekly_cost_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        recommended_budget_estimated_change_weekly_interactions: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        recommended_budget_estimated_change_weekly_views: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        type: typing___Optional[
            google___ads___googleads___v3___enums___budget_type_pb2___BudgetTypeEnum.BudgetTypeValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "amount_micros",
            b"amount_micros",
            "explicitly_shared",
            b"explicitly_shared",
            "has_recommended_budget",
            b"has_recommended_budget",
            "id",
            b"id",
            "name",
            b"name",
            "recommended_budget_amount_micros",
            b"recommended_budget_amount_micros",
            "recommended_budget_estimated_change_weekly_clicks",
            b"recommended_budget_estimated_change_weekly_clicks",
            "recommended_budget_estimated_change_weekly_cost_micros",
            b"recommended_budget_estimated_change_weekly_cost_micros",
            "recommended_budget_estimated_change_weekly_interactions",
            b"recommended_budget_estimated_change_weekly_interactions",
            "recommended_budget_estimated_change_weekly_views",
            b"recommended_budget_estimated_change_weekly_views",
            "reference_count",
            b"reference_count",
            "total_amount_micros",
            b"total_amount_micros",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "amount_micros",
            b"amount_micros",
            "delivery_method",
            b"delivery_method",
            "explicitly_shared",
            b"explicitly_shared",
            "has_recommended_budget",
            b"has_recommended_budget",
            "id",
            b"id",
            "name",
            b"name",
            "period",
            b"period",
            "recommended_budget_amount_micros",
            b"recommended_budget_amount_micros",
            "recommended_budget_estimated_change_weekly_clicks",
            b"recommended_budget_estimated_change_weekly_clicks",
            "recommended_budget_estimated_change_weekly_cost_micros",
            b"recommended_budget_estimated_change_weekly_cost_micros",
            "recommended_budget_estimated_change_weekly_interactions",
            b"recommended_budget_estimated_change_weekly_interactions",
            "recommended_budget_estimated_change_weekly_views",
            b"recommended_budget_estimated_change_weekly_views",
            "reference_count",
            b"reference_count",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
            "total_amount_micros",
            b"total_amount_micros",
            "type",
            b"type",
        ],
    ) -> None: ...

type___CampaignBudget = CampaignBudget



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PromotionExtensionOccasionEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PromotionExtensionOccasionValue = typing___NewType(
        "PromotionExtensionOccasionValue", builtin___int
    )
    type___PromotionExtensionOccasionValue = PromotionExtensionOccasionValue
    PromotionExtensionOccasion: _PromotionExtensionOccasion
    class _PromotionExtensionOccasion(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 0
        )
        UNKNOWN = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 1
        )
        NEW_YEARS = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 2
        )
        CHINESE_NEW_YEAR = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 3
        )
        VALENTINES_DAY = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 4
        )
        EASTER = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 5
        )
        MOTHERS_DAY = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 6
        )
        FATHERS_DAY = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 7
        )
        LABOR_DAY = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 8
        )
        BACK_TO_SCHOOL = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 9
        )
        HALLOWEEN = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 10
        )
        BLACK_FRIDAY = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 11
        )
        CYBER_MONDAY = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 12
        )
        CHRISTMAS = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 13
        )
        BOXING_DAY = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 14
        )
        INDEPENDENCE_DAY = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 15
        )
        NATIONAL_DAY = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 16
        )
        END_OF_SEASON = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 17
        )
        WINTER_SALE = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 18
        )
        SUMMER_SALE = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 19
        )
        FALL_SALE = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 20
        )
        SPRING_SALE = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 21
        )
        RAMADAN = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 22
        )
        EID_AL_FITR = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 23
        )
        EID_AL_ADHA = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 24
        )
        SINGLES_DAY = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 25
        )
        WOMENS_DAY = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 26
        )
        HOLI = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 27
        )
        PARENTS_DAY = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 28
        )
        ST_NICHOLAS_DAY = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 29
        )
        CARNIVAL = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 30
        )
        EPIPHANY = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 31
        )
        ROSH_HASHANAH = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 32
        )
        PASSOVER = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 33
        )
        HANUKKAH = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 34
        )
        DIWALI = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 35
        )
        NAVRATRI = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 36
        )
        SONGKRAN = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 37
        )
        YEAR_END_GIFT = typing___cast(
            PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 38
        )
    UNSPECIFIED = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 0
    )
    UNKNOWN = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 1
    )
    NEW_YEARS = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 2
    )
    CHINESE_NEW_YEAR = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 3
    )
    VALENTINES_DAY = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 4
    )
    EASTER = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 5
    )
    MOTHERS_DAY = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 6
    )
    FATHERS_DAY = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 7
    )
    LABOR_DAY = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 8
    )
    BACK_TO_SCHOOL = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 9
    )
    HALLOWEEN = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 10
    )
    BLACK_FRIDAY = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 11
    )
    CYBER_MONDAY = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 12
    )
    CHRISTMAS = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 13
    )
    BOXING_DAY = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 14
    )
    INDEPENDENCE_DAY = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 15
    )
    NATIONAL_DAY = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 16
    )
    END_OF_SEASON = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 17
    )
    WINTER_SALE = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 18
    )
    SUMMER_SALE = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 19
    )
    FALL_SALE = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 20
    )
    SPRING_SALE = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 21
    )
    RAMADAN = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 22
    )
    EID_AL_FITR = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 23
    )
    EID_AL_ADHA = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 24
    )
    SINGLES_DAY = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 25
    )
    WOMENS_DAY = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 26
    )
    HOLI = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 27
    )
    PARENTS_DAY = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 28
    )
    ST_NICHOLAS_DAY = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 29
    )
    CARNIVAL = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 30
    )
    EPIPHANY = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 31
    )
    ROSH_HASHANAH = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 32
    )
    PASSOVER = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 33
    )
    HANUKKAH = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 34
    )
    DIWALI = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 35
    )
    NAVRATRI = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 36
    )
    SONGKRAN = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 37
    )
    YEAR_END_GIFT = typing___cast(
        PromotionExtensionOccasionEnum.PromotionExtensionOccasionValue, 38
    )
    type___PromotionExtensionOccasion = PromotionExtensionOccasion
    def __init__(self,) -> None: ...

type___PromotionExtensionOccasionEnum = PromotionExtensionOccasionEnum



from typing import Any

class RecommendationServiceStub:
    GetRecommendation: Any = ...
    ApplyRecommendation: Any = ...
    DismissRecommendation: Any = ...
    def __init__(self, channel: Any) -> None: ...

class RecommendationServiceServicer:
    def GetRecommendation(self, request: Any, context: Any) -> None: ...
    def ApplyRecommendation(self, request: Any, context: Any) -> None: ...
    def DismissRecommendation(self, request: Any, context: Any) -> None: ...

def add_RecommendationServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AuthorizationErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AuthorizationErrorValue = typing___NewType("AuthorizationErrorValue", builtin___int)
    type___AuthorizationErrorValue = AuthorizationErrorValue
    AuthorizationError: _AuthorizationError
    class _AuthorizationError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AuthorizationErrorEnum.AuthorizationErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AuthorizationErrorEnum.AuthorizationErrorValue, 0)
        UNKNOWN = typing___cast(AuthorizationErrorEnum.AuthorizationErrorValue, 1)
        USER_PERMISSION_DENIED = typing___cast(
            AuthorizationErrorEnum.AuthorizationErrorValue, 2
        )
        DEVELOPER_TOKEN_NOT_ON_ALLOWLIST = typing___cast(
            AuthorizationErrorEnum.AuthorizationErrorValue, 13
        )
        DEVELOPER_TOKEN_PROHIBITED = typing___cast(
            AuthorizationErrorEnum.AuthorizationErrorValue, 4
        )
        PROJECT_DISABLED = typing___cast(
            AuthorizationErrorEnum.AuthorizationErrorValue, 5
        )
        AUTHORIZATION_ERROR = typing___cast(
            AuthorizationErrorEnum.AuthorizationErrorValue, 6
        )
        ACTION_NOT_PERMITTED = typing___cast(
            AuthorizationErrorEnum.AuthorizationErrorValue, 7
        )
        INCOMPLETE_SIGNUP = typing___cast(
            AuthorizationErrorEnum.AuthorizationErrorValue, 8
        )
        CUSTOMER_NOT_ENABLED = typing___cast(
            AuthorizationErrorEnum.AuthorizationErrorValue, 24
        )
        MISSING_TOS = typing___cast(AuthorizationErrorEnum.AuthorizationErrorValue, 9)
        DEVELOPER_TOKEN_NOT_APPROVED = typing___cast(
            AuthorizationErrorEnum.AuthorizationErrorValue, 10
        )
        INVALID_LOGIN_CUSTOMER_ID_SERVING_CUSTOMER_ID_COMBINATION = typing___cast(
            AuthorizationErrorEnum.AuthorizationErrorValue, 11
        )
        SERVICE_ACCESS_DENIED = typing___cast(
            AuthorizationErrorEnum.AuthorizationErrorValue, 12
        )
    UNSPECIFIED = typing___cast(AuthorizationErrorEnum.AuthorizationErrorValue, 0)
    UNKNOWN = typing___cast(AuthorizationErrorEnum.AuthorizationErrorValue, 1)
    USER_PERMISSION_DENIED = typing___cast(
        AuthorizationErrorEnum.AuthorizationErrorValue, 2
    )
    DEVELOPER_TOKEN_NOT_ON_ALLOWLIST = typing___cast(
        AuthorizationErrorEnum.AuthorizationErrorValue, 13
    )
    DEVELOPER_TOKEN_PROHIBITED = typing___cast(
        AuthorizationErrorEnum.AuthorizationErrorValue, 4
    )
    PROJECT_DISABLED = typing___cast(AuthorizationErrorEnum.AuthorizationErrorValue, 5)
    AUTHORIZATION_ERROR = typing___cast(
        AuthorizationErrorEnum.AuthorizationErrorValue, 6
    )
    ACTION_NOT_PERMITTED = typing___cast(
        AuthorizationErrorEnum.AuthorizationErrorValue, 7
    )
    INCOMPLETE_SIGNUP = typing___cast(AuthorizationErrorEnum.AuthorizationErrorValue, 8)
    CUSTOMER_NOT_ENABLED = typing___cast(
        AuthorizationErrorEnum.AuthorizationErrorValue, 24
    )
    MISSING_TOS = typing___cast(AuthorizationErrorEnum.AuthorizationErrorValue, 9)
    DEVELOPER_TOKEN_NOT_APPROVED = typing___cast(
        AuthorizationErrorEnum.AuthorizationErrorValue, 10
    )
    INVALID_LOGIN_CUSTOMER_ID_SERVING_CUSTOMER_ID_COMBINATION = typing___cast(
        AuthorizationErrorEnum.AuthorizationErrorValue, 11
    )
    SERVICE_ACCESS_DENIED = typing___cast(
        AuthorizationErrorEnum.AuthorizationErrorValue, 12
    )
    type___AuthorizationError = AuthorizationError
    def __init__(self,) -> None: ...

type___AuthorizationErrorEnum = AuthorizationErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ProductConditionEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ProductConditionValue = typing___NewType("ProductConditionValue", builtin___int)
    type___ProductConditionValue = ProductConditionValue
    ProductCondition: _ProductCondition
    class _ProductCondition(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ProductConditionEnum.ProductConditionValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ProductConditionEnum.ProductConditionValue, 0)
        UNKNOWN = typing___cast(ProductConditionEnum.ProductConditionValue, 1)
        NEW = typing___cast(ProductConditionEnum.ProductConditionValue, 3)
        REFURBISHED = typing___cast(ProductConditionEnum.ProductConditionValue, 4)
        USED = typing___cast(ProductConditionEnum.ProductConditionValue, 5)
    UNSPECIFIED = typing___cast(ProductConditionEnum.ProductConditionValue, 0)
    UNKNOWN = typing___cast(ProductConditionEnum.ProductConditionValue, 1)
    NEW = typing___cast(ProductConditionEnum.ProductConditionValue, 3)
    REFURBISHED = typing___cast(ProductConditionEnum.ProductConditionValue, 4)
    USED = typing___cast(ProductConditionEnum.ProductConditionValue, 5)
    type___ProductCondition = ProductCondition
    def __init__(self,) -> None: ...

type___ProductConditionEnum = ProductConditionEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class CustomerClientLinkErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    CustomerClientLinkErrorValue = typing___NewType(
        "CustomerClientLinkErrorValue", builtin___int
    )
    type___CustomerClientLinkErrorValue = CustomerClientLinkErrorValue
    CustomerClientLinkError: _CustomerClientLinkError
    class _CustomerClientLinkError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 0
        )
        UNKNOWN = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 1
        )
        CLIENT_ALREADY_INVITED_BY_THIS_MANAGER = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 2
        )
        CLIENT_ALREADY_MANAGED_IN_HIERARCHY = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 3
        )
        CYCLIC_LINK_NOT_ALLOWED = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 4
        )
        CUSTOMER_HAS_TOO_MANY_ACCOUNTS = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 5
        )
        CLIENT_HAS_TOO_MANY_INVITATIONS = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 6
        )
        CANNOT_HIDE_OR_UNHIDE_MANAGER_ACCOUNTS = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 7
        )
        CUSTOMER_HAS_TOO_MANY_ACCOUNTS_AT_MANAGER = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 8
        )
        CLIENT_HAS_TOO_MANY_MANAGERS = typing___cast(
            CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 9
        )
    UNSPECIFIED = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 0
    )
    UNKNOWN = typing___cast(CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 1)
    CLIENT_ALREADY_INVITED_BY_THIS_MANAGER = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 2
    )
    CLIENT_ALREADY_MANAGED_IN_HIERARCHY = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 3
    )
    CYCLIC_LINK_NOT_ALLOWED = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 4
    )
    CUSTOMER_HAS_TOO_MANY_ACCOUNTS = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 5
    )
    CLIENT_HAS_TOO_MANY_INVITATIONS = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 6
    )
    CANNOT_HIDE_OR_UNHIDE_MANAGER_ACCOUNTS = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 7
    )
    CUSTOMER_HAS_TOO_MANY_ACCOUNTS_AT_MANAGER = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 8
    )
    CLIENT_HAS_TOO_MANY_MANAGERS = typing___cast(
        CustomerClientLinkErrorEnum.CustomerClientLinkErrorValue, 9
    )
    type___CustomerClientLinkError = CustomerClientLinkError
    def __init__(self,) -> None: ...

type___CustomerClientLinkErrorEnum = CustomerClientLinkErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AssetLinkErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AssetLinkErrorValue = typing___NewType("AssetLinkErrorValue", builtin___int)
    type___AssetLinkErrorValue = AssetLinkErrorValue
    AssetLinkError: _AssetLinkError
    class _AssetLinkError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AssetLinkErrorEnum.AssetLinkErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AssetLinkErrorEnum.AssetLinkErrorValue, 0)
        UNKNOWN = typing___cast(AssetLinkErrorEnum.AssetLinkErrorValue, 1)
        PINNING_UNSUPPORTED = typing___cast(AssetLinkErrorEnum.AssetLinkErrorValue, 2)
        UNSUPPORTED_FIELD_TYPE = typing___cast(
            AssetLinkErrorEnum.AssetLinkErrorValue, 3
        )
        FIELD_TYPE_INCOMPATIBLE_WITH_ASSET_TYPE = typing___cast(
            AssetLinkErrorEnum.AssetLinkErrorValue, 4
        )
        FIELD_TYPE_INCOMPATIBLE_WITH_CAMPAIGN_TYPE = typing___cast(
            AssetLinkErrorEnum.AssetLinkErrorValue, 5
        )
        INCOMPATIBLE_ADVERTISING_CHANNEL_TYPE = typing___cast(
            AssetLinkErrorEnum.AssetLinkErrorValue, 6
        )
    UNSPECIFIED = typing___cast(AssetLinkErrorEnum.AssetLinkErrorValue, 0)
    UNKNOWN = typing___cast(AssetLinkErrorEnum.AssetLinkErrorValue, 1)
    PINNING_UNSUPPORTED = typing___cast(AssetLinkErrorEnum.AssetLinkErrorValue, 2)
    UNSUPPORTED_FIELD_TYPE = typing___cast(AssetLinkErrorEnum.AssetLinkErrorValue, 3)
    FIELD_TYPE_INCOMPATIBLE_WITH_ASSET_TYPE = typing___cast(
        AssetLinkErrorEnum.AssetLinkErrorValue, 4
    )
    FIELD_TYPE_INCOMPATIBLE_WITH_CAMPAIGN_TYPE = typing___cast(
        AssetLinkErrorEnum.AssetLinkErrorValue, 5
    )
    INCOMPATIBLE_ADVERTISING_CHANNEL_TYPE = typing___cast(
        AssetLinkErrorEnum.AssetLinkErrorValue, 6
    )
    type___AssetLinkError = AssetLinkError
    def __init__(self,) -> None: ...

type___AssetLinkErrorEnum = AssetLinkErrorEnum



from typing import Any

class ParentalStatusViewServiceStub:
    GetParentalStatusView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ParentalStatusViewServiceServicer:
    def GetParentalStatusView(self, request: Any, context: Any) -> None: ...

def add_ParentalStatusViewServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AssetFieldTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AssetFieldTypeValue = typing___NewType("AssetFieldTypeValue", builtin___int)
    type___AssetFieldTypeValue = AssetFieldTypeValue
    AssetFieldType: _AssetFieldType
    class _AssetFieldType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AssetFieldTypeEnum.AssetFieldTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 0)
        UNKNOWN = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 1)
        HEADLINE = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 2)
        DESCRIPTION = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 3)
        MANDATORY_AD_TEXT = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 4)
        MARKETING_IMAGE = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 5)
        MEDIA_BUNDLE = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 6)
        YOUTUBE_VIDEO = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 7)
        BOOK_ON_GOOGLE = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 8)
        LEAD_FORM = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 9)
    UNSPECIFIED = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 0)
    UNKNOWN = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 1)
    HEADLINE = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 2)
    DESCRIPTION = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 3)
    MANDATORY_AD_TEXT = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 4)
    MARKETING_IMAGE = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 5)
    MEDIA_BUNDLE = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 6)
    YOUTUBE_VIDEO = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 7)
    BOOK_ON_GOOGLE = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 8)
    LEAD_FORM = typing___cast(AssetFieldTypeEnum.AssetFieldTypeValue, 9)
    type___AssetFieldType = AssetFieldType
    def __init__(self,) -> None: ...

type___AssetFieldTypeEnum = AssetFieldTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class DomainCategory(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    campaign: typing___Text = ...
    category: typing___Text = ...
    language_code: typing___Text = ...
    domain: typing___Text = ...
    coverage_fraction: builtin___float = ...
    category_rank: builtin___int = ...
    has_children: builtin___bool = ...
    recommended_cpc_bid_micros: builtin___int = ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        campaign: typing___Optional[typing___Text] = None,
        category: typing___Optional[typing___Text] = None,
        language_code: typing___Optional[typing___Text] = None,
        domain: typing___Optional[typing___Text] = None,
        coverage_fraction: typing___Optional[builtin___float] = None,
        category_rank: typing___Optional[builtin___int] = None,
        has_children: typing___Optional[builtin___bool] = None,
        recommended_cpc_bid_micros: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_campaign",
            b"_campaign",
            "_category",
            b"_category",
            "_category_rank",
            b"_category_rank",
            "_coverage_fraction",
            b"_coverage_fraction",
            "_domain",
            b"_domain",
            "_has_children",
            b"_has_children",
            "_language_code",
            b"_language_code",
            "_recommended_cpc_bid_micros",
            b"_recommended_cpc_bid_micros",
            "campaign",
            b"campaign",
            "category",
            b"category",
            "category_rank",
            b"category_rank",
            "coverage_fraction",
            b"coverage_fraction",
            "domain",
            b"domain",
            "has_children",
            b"has_children",
            "language_code",
            b"language_code",
            "recommended_cpc_bid_micros",
            b"recommended_cpc_bid_micros",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_campaign",
            b"_campaign",
            "_category",
            b"_category",
            "_category_rank",
            b"_category_rank",
            "_coverage_fraction",
            b"_coverage_fraction",
            "_domain",
            b"_domain",
            "_has_children",
            b"_has_children",
            "_language_code",
            b"_language_code",
            "_recommended_cpc_bid_micros",
            b"_recommended_cpc_bid_micros",
            "campaign",
            b"campaign",
            "category",
            b"category",
            "category_rank",
            b"category_rank",
            "coverage_fraction",
            b"coverage_fraction",
            "domain",
            b"domain",
            "has_children",
            b"has_children",
            "language_code",
            b"language_code",
            "recommended_cpc_bid_micros",
            b"recommended_cpc_bid_micros",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_campaign", b"_campaign"]
    ) -> typing_extensions___Literal["campaign"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_category", b"_category"]
    ) -> typing_extensions___Literal["category"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_category_rank", b"_category_rank"],
    ) -> typing_extensions___Literal["category_rank"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_coverage_fraction", b"_coverage_fraction"
        ],
    ) -> typing_extensions___Literal["coverage_fraction"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_domain", b"_domain"]
    ) -> typing_extensions___Literal["domain"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_has_children", b"_has_children"],
    ) -> typing_extensions___Literal["has_children"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_language_code", b"_language_code"],
    ) -> typing_extensions___Literal["language_code"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_recommended_cpc_bid_micros", b"_recommended_cpc_bid_micros"
        ],
    ) -> typing_extensions___Literal["recommended_cpc_bid_micros"]: ...

type___DomainCategory = DomainCategory



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.mime_type_pb2 import (
    MimeTypeEnum as google___ads___googleads___v5___enums___mime_type_pb2___MimeTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class YoutubeVideoAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    youtube_video_id: typing___Text = ...
    def __init__(
        self, *, youtube_video_id: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_youtube_video_id",
            b"_youtube_video_id",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_youtube_video_id",
            b"_youtube_video_id",
            "youtube_video_id",
            b"youtube_video_id",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_youtube_video_id", b"_youtube_video_id"
        ],
    ) -> typing_extensions___Literal["youtube_video_id"]: ...

type___YoutubeVideoAsset = YoutubeVideoAsset

class MediaBundleAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    data: builtin___bytes = ...
    def __init__(self, *, data: typing___Optional[builtin___bytes] = None,) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["_data", b"_data", "data", b"data"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["_data", b"_data", "data", b"data"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_data", b"_data"]
    ) -> typing_extensions___Literal["data"]: ...

type___MediaBundleAsset = MediaBundleAsset

class ImageAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    data: builtin___bytes = ...
    file_size: builtin___int = ...
    mime_type: google___ads___googleads___v5___enums___mime_type_pb2___MimeTypeEnum.MimeTypeValue = ...
    @property
    def full_size(self) -> type___ImageDimension: ...
    def __init__(
        self,
        *,
        data: typing___Optional[builtin___bytes] = None,
        file_size: typing___Optional[builtin___int] = None,
        mime_type: typing___Optional[
            google___ads___googleads___v5___enums___mime_type_pb2___MimeTypeEnum.MimeTypeValue
        ] = None,
        full_size: typing___Optional[type___ImageDimension] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_data",
            b"_data",
            "_file_size",
            b"_file_size",
            "data",
            b"data",
            "file_size",
            b"file_size",
            "full_size",
            b"full_size",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_data",
            b"_data",
            "_file_size",
            b"_file_size",
            "data",
            b"data",
            "file_size",
            b"file_size",
            "full_size",
            b"full_size",
            "mime_type",
            b"mime_type",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_data", b"_data"]
    ) -> typing_extensions___Literal["data"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_file_size", b"_file_size"]
    ) -> typing_extensions___Literal["file_size"]: ...

type___ImageAsset = ImageAsset

class ImageDimension(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    height_pixels: builtin___int = ...
    width_pixels: builtin___int = ...
    url: typing___Text = ...
    def __init__(
        self,
        *,
        height_pixels: typing___Optional[builtin___int] = None,
        width_pixels: typing___Optional[builtin___int] = None,
        url: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_height_pixels",
            b"_height_pixels",
            "_url",
            b"_url",
            "_width_pixels",
            b"_width_pixels",
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_height_pixels",
            b"_height_pixels",
            "_url",
            b"_url",
            "_width_pixels",
            b"_width_pixels",
            "height_pixels",
            b"height_pixels",
            "url",
            b"url",
            "width_pixels",
            b"width_pixels",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_height_pixels", b"_height_pixels"],
    ) -> typing_extensions___Literal["height_pixels"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_url", b"_url"]
    ) -> typing_extensions___Literal["url"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_width_pixels", b"_width_pixels"],
    ) -> typing_extensions___Literal["width_pixels"]: ...

type___ImageDimension = ImageDimension

class TextAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    text: typing___Text = ...
    def __init__(self, *, text: typing___Optional[typing___Text] = None,) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal["_text", b"_text", "text", b"text"],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["_text", b"_text", "text", b"text"],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_text", b"_text"]
    ) -> typing_extensions___Literal["text"]: ...

type___TextAsset = TextAsset

class BookOnGoogleAsset(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    def __init__(self,) -> None: ...

type___BookOnGoogleAsset = BookOnGoogleAsset



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.common.matching_function_pb2 import (
    MatchingFunction as google___ads___googleads___v5___common___matching_function_pb2___MatchingFunction,
)
from google.ads.google_ads.v5.proto.enums.feed_link_status_pb2 import (
    FeedLinkStatusEnum as google___ads___googleads___v5___enums___feed_link_status_pb2___FeedLinkStatusEnum,
)
from google.ads.google_ads.v5.proto.enums.placeholder_type_pb2 import (
    PlaceholderTypeEnum as google___ads___googleads___v5___enums___placeholder_type_pb2___PlaceholderTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AdGroupFeed(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    placeholder_types: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        google___ads___googleads___v5___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderTypeValue
    ] = ...
    status: google___ads___googleads___v5___enums___feed_link_status_pb2___FeedLinkStatusEnum.FeedLinkStatusValue = ...
    @property
    def feed(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def matching_function(
        self,
    ) -> google___ads___googleads___v5___common___matching_function_pb2___MatchingFunction: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        feed: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ad_group: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        placeholder_types: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v5___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderTypeValue
            ]
        ] = None,
        matching_function: typing___Optional[
            google___ads___googleads___v5___common___matching_function_pb2___MatchingFunction
        ] = None,
        status: typing___Optional[
            google___ads___googleads___v5___enums___feed_link_status_pb2___FeedLinkStatusEnum.FeedLinkStatusValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group",
            b"ad_group",
            "feed",
            b"feed",
            "matching_function",
            b"matching_function",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group",
            b"ad_group",
            "feed",
            b"feed",
            "matching_function",
            b"matching_function",
            "placeholder_types",
            b"placeholder_types",
            "resource_name",
            b"resource_name",
            "status",
            b"status",
        ],
    ) -> None: ...

type___AdGroupFeed = AdGroupFeed
